"""
:py:mod:`tests.integration.test_types`

Tests for the :py:mod:`xtract.types` module.


Copyright (C) 2016-2017 Mathias Stelzer

xtract is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

xtract is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
from __future__ import absolute_import, print_function, unicode_literals

import unittest

from distutils.spawn import find_executable
from base import BaseTestCase, BaseXtractFileTests, BaseXtractDirectoryTests
from xtract.types import Rar, Zip, Tar, GZip, XZ, BZip2


class BaseGetXtractDestinationTestCase(BaseTestCase):
    def call(self, *args, **kwargs):
        return self.typ().get_xtract_destination(*args, **kwargs)


class XtractFileDestinationTests(BaseXtractFileTests):
    def test_file(self):
        result = super(XtractFileDestinationTests, self).test_file()
        self.assertEqual(self.file, result)

    def test_file_destination(self):
        result = super(XtractFileDestinationTests, self).test_file_destination()
        self.assertEqual(self.destination, result)

    def test_file_destination_directory(self):
        result = super(XtractFileDestinationTests, self).test_file_destination_directory()
        self.assertEqual(self.destination, result)

    def test_file_destination_exists(self):
        result = super(XtractFileDestinationTests, self).test_file_destination_exists()
        self.assertEqual(self.destination, result)

    def test_file_mimetype(self):
        result = super(XtractFileDestinationTests, self).test_file_mimetype()
        self.assertEqual(self.destination, result)

    def test_file_mimetype_destination(self):
        result = super(XtractFileDestinationTests, self).test_file_mimetype_destination()
        self.assertEqual(self.destination, result)

    def test_file_mimetype_destination_directory(self):
        result = super(XtractFileDestinationTests, self).test_file_mimetype_destination_directory()
        self.assertEqual(self.destination, result)


class XtractDirectoryDestinationTests(BaseXtractDirectoryTests):
    def test_directory(self):
        result = super(XtractDirectoryDestinationTests, self).test_directory()
        self.assertEqual(self.dir, result)

    def test_directory_destination(self):
        result = super(XtractDirectoryDestinationTests, self).test_directory_destination()
        self.assertEqual(self.destination, result)

    def test_directory_destination_directory(self):
        result = super(XtractDirectoryDestinationTests, self).test_directory_destination_directory()
        self.assertEqual(self.dir, result)


@unittest.skipUnless(find_executable('rar'), 'rar is not installed')
@unittest.skipUnless(find_executable('unrar'), 'unrar is not installed')
class RarGetUnpackSourceTestCase(XtractDirectoryDestinationTests, XtractFileDestinationTests, BaseGetXtractDestinationTestCase):
    typ = Rar


@unittest.skipUnless(find_executable('zip'), 'zip is not installed')
@unittest.skipUnless(find_executable('unzip'), 'unzip is not installed')
class ZipGetUnpackSourceTestCase(XtractDirectoryDestinationTests, XtractFileDestinationTests, BaseGetXtractDestinationTestCase):
    typ = Zip


@unittest.skipUnless(find_executable('tar'), 'tar is not installed')
class TarGetUnpackSourceTestCase(XtractDirectoryDestinationTests, XtractFileDestinationTests, BaseGetXtractDestinationTestCase):
    typ = Tar


@unittest.skipUnless(find_executable('gzip'), 'gzip is not installed')
class GZipGetUnpackSourceTestCase(XtractFileDestinationTests, BaseGetXtractDestinationTestCase):
    typ = GZip


@unittest.skipUnless(find_executable('xz'), 'xz is not installed')
class XZGetUnpackSourceTestCase(XtractFileDestinationTests, BaseGetXtractDestinationTestCase):
    typ = XZ


@unittest.skipUnless(find_executable('bzip2'), 'bzip2 is not installed')
class BZip2GetUnpackSourceTestCase(XtractFileDestinationTests, BaseGetXtractDestinationTestCase):
    typ = BZip2

